==> tine20-allinone_2019.12.5.tar.bz2: Filemanager/js/Filemanager-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: fi\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Upload Failed"
: "Tallennus epäonnistu"

, "Putting files in this folder is not allowed!"
: "Tähän kansioon ei ole sallittua lisätä tiedostoja."

, "Filemanager"
: "Tiedostonhallinta"

, "Save locally"
: "Tallenna paikallisesti"

, "Tags"
: "Avainsanat"

, "Name"
: "Nimi"

, "Size"
: "Koko"

, "Contenttype"
: "Sisällön tyyppi"

, "Folder, Folders"
: [
  "Kansio"
 ,"Kansiot"

]
, "Creation Time"
: "Luontiaika"

, "Created By"
: "Luonut"

, "Last Modified Time"
: "Muokattu viimeksi"

, "Last Modified By"
: "Muokannut viimeksi"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Tallenna"

, "Open Data Safe"
: ""

, "Folder Up"
: "Kansio ylöspäin"

, "Close Data Safe"
: ""

, "Node Download Links"
: ""

, "Url"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Service Unavailable"
: "Palvelu ei käytössä"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Tiedostonhallintaa ei ole määritelty oikein. Katso {0}Tine 2.0 Admin FAQ{1} tai ota yhteyttä järjestelmän valvojaan."

, "Files already exists"
: "Tiedostot jo olemassa"

, "Do you want to replace the following file(s)?"
: "Haluatko poistaa seuraavat tiedostot?"

, "Failure on create folder"
: "Virhe luotaessa kansiota?"

, "Item with this name already exists!"
: "Samanniminen tiedosto jo olemassa!"

, "Revision"
: "Versio"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "path"
: "polku"

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Reload"
: ""

, "Create Folder"
: "Luo kansio"

, "New Folder"
: "Uusi kansio"

, "Please enter the name of the new folder:"
: "Kirjoita uuden kansion nimi:"

, "No {0} added"
: "{0} ei lisätty"

, "You have to supply a {0} name!"
: "Anna {0} nimi."

, "Edit Properties"
: "Muokkaa asetuksia"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Nimeä uudestaan tiedosto {0}:"

, "Not renamed {0}"
: "Ei uudelleen nimetty {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Poista"

, "Do you really want to delete the following files?"
: "Haluatko poistaa seuraavat tiedostot?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Publish"
: ""

, "Public download links can be password protected. If left blank anyone who knows the link can download the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "File, Files"
: [
  "Tiedosto"
 ,"Tiedostot"

]
, "The grant to download files"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopioidaan tietoja .. {0}"

, "Moving data .. {0}"
: "Siirretään tietoja .. {0}"

, "Please wait"
: "Odota hetki"

, "Quick Search"
: ""

, "Type"
: "Tyyppi"

, "Description"
: "Kuvaus"

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Grants"
: ""

, "This folder has own grants"
: ""

, "Grants of a folder also apply recursively for all of its sub folders as long they don't have own grants itself."
: ""

, "This folder is part of the data safe"
: ""

, "If data safe protection is enabled, this folder and all it's contents is only shown if the data safe is opened."
: ""

, "Sorry, Tine 2.0 would like to show you the contents of the file displayed."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We are happy make you a non-binding offer."
: ""

, "No preview available."
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Remove record"
: ""

, "Search for groups ..."
: ""

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Not yet indexed"
: ""

, "Modified By"
: "Muokannut"

, "Last Modified"
: "Muokattu viimeksi"

, "Enter description"
: "Lisää kuvaus"

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Create Public Link"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "no quota set"
: ""

, "Current Usage"
: ""

, "The Quota applies recursively for files and subfolders. Please note, the Effective Quota differs wehn a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "Row double click default"
: ""

, "Defines which action should be executed on double click by default?"
: ""

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Public Download URL"
: ""

, "Serve anonymous downloads from a different URL. Make sure to setup proper rewrite rules."
: ""

, "manage shared folders"
: "hallitse jaettuja kansioita"

, "Create new shared folders"
: "Luo uusi jaettu kansio"

, "Manage anonymous download links"
: ""

, "Allow to see, add and delete download links of files and folders"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path the source has. No action has been performed."
: ""

, "My folders"
: "Omat kansiot"

, "Shared folders"
: "Jaetut kansiot"

, "Other users folders"
: "Muiden käyttäjien kansiot"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Folder"
: "Kansio"

, "File"
: "Tiedosto"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2020.08.8.tar.bz2: Filemanager/js/Filemanager-lang-fi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Filemanager **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Filemanager'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Finnish (http://www.transifex.com/tine20/tine20/language/fi/)\nLanguage: fi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Password for download required"
: ""

, "Submit"
: ""

, "File not found!"
: ""

, "Name"
: "Nimi"

, "Size"
: "Koko"

, "Last Modified"
: "Muokattu viimeksi"

, "Description"
: "Kuvaus"

, "Folder, Folders"
: [
  "Kansio"
 ,"Kansiot"

]
, "File, Files"
: [
  "Tiedosto"
 ,"Tiedostot"

]
, "Default behavior when double-clicking on a Row"
: ""

, "Defines which action should be executed by default when double-clicked."
: ""

, "Invalid Filename"
: ""

, "Content type"
: ""

, "path"
: "polku"

, "URL"
: ""

, "Password"
: ""

, "Valid until"
: ""

, "Send as e-mail"
: ""

, "Download"
: ""

, "Create Public Link"
: ""

, "Remove record"
: ""

, "Creating new Download Link..."
: ""

, "Deleting Download Links..."
: ""

, "Deleting Download Link..."
: ""

, "Created By"
: "Luonut"

, "Creation Time"
: "Luontiaika"

, "Expiration Time"
: ""

, "Access Count"
: ""

, "Last Modified Time"
: "Muokattu viimeksi"

, "Last Modified By"
: "Muokannut viimeksi"

, "Revision"
: "Versio"

, "This folder has own revision settings"
: ""

, "Revision active"
: ""

, "Limit revision amount to"
: ""

, "Hold-back in months"
: ""

, "Upload Failed"
: "Tallennus epäonnistu"

, "It is not permitted to store files in this folder!"
: ""

, "Select a file"
: ""

, "Select files"
: ""

, "Select a folder"
: ""

, "Select folders"
: ""

, "Select an item"
: ""

, "Select items"
: ""

, "Checking ..."
: ""

, "Overwrite Existing File?"
: ""

, "Do you really want to overwrite the selected file?"
: ""

, "Tags"
: "Avainsanat"

, "Revision Size"
: ""

, "Total size of all available revisions"
: ""

, "Indexed"
: ""

, "File contents is part of the search index"
: ""

, "Upload"
: "Tallenna"

, "Open Data Safe"
: ""

, "Folder Up"
: "Kansio ylöspäin"

, "Close Data Safe"
: ""

, "Filemanager"
: "Tiedostonhallinta"

, "Save locally"
: "Tallenna paikallisesti"

, "Close"
: ""

, "Loading preview ..."
: ""

, "Edit folder"
: ""

, "edit file"
: ""

, "Public Links"
: ""

, "Type"
: "Tyyppi"

, "Not yet indexed"
: ""

, "Modified By"
: "Muokannut"

, "Enter description"
: "Lisää kuvaus"

, "Service Unavailable"
: "Palvelu ei käytössä"

, "The Filemanager is not configured correctly. Please refer to the {0}Tine 2.0 Admin FAQ{1} for configuration advice or contact your administrator."
: "Tiedostonhallintaa ei ole määritelty oikein. Katso {0}Tine 2.0 Admin FAQ{1} tai ota yhteyttä järjestelmän valvojaan."

, "File(s) already exists"
: ""

, "Do you want to replace the following file(s)?"
: "Haluatko poistaa seuraavat tiedostot?"

, "An error occurred creating this folder"
: ""

, "Item with this name already exists!"
: "Samanniminen tiedosto jo olemassa!"

, "Whole Filemanager"
: ""

, "This Folder"
: ""

, "Search"
: ""

, "The grant to download files"
: ""

, "Publish"
: ""

, "The grant to create anonymous download links for files"
: ""

, "Copying data .. {0}"
: "Kopioidaan tietoja .. {0}"

, "Moving data .. {0}"
: "Siirretään tietoja .. {0}"

, "Please wait"
: "Odota hetki"

, "Error while uploading \"{fileName}\". Please try again later."
: ""

, "Quick Search"
: ""

, "Content Type"
: ""

, "File Contents"
: ""

, "Download Link, Download Links"
: [
  ""
 ,""

]
, "Node Download Links"
: ""

, "Sorry, Tine 2.0 would have liked to show you the contents of the file."
: ""

, "This is possible for .doc, .jpg, .pdf and even more file formats."
: ""

, "Interested? Then let us know!"
: ""

, "We would be happy to make you a non-binding offer."
: ""

, "No preview available yet - Please try again in a few minutes."
: ""

, "Notifications"
: ""

, "This folder has own notification settings"
: ""

, "Notification"
: ""

, "Notification active"
: ""

, "Summary"
: ""

, "Once a Day, Every {0} Days"
: [
  ""
 ,""

]
, "No"
: ""

, "Don't summarize"
: ""

, "Once a day"
: ""

, "Every 3 days"
: ""

, "Once a week"
: ""

, "Once a month"
: ""

, "Once a year"
: ""

, "Search for users ..."
: ""

, "No permission"
: ""

, "all"
: ""

, "Search for groups ..."
: ""

, "Grants"
: ""

, "This folder has its own grants"
: ""

, "Grants of a folder also apply recursively to all sub folders unless they have their own grants."
: ""

, "This folder is part of the data safe"
: ""

, "If the data safe is activated, this folder and its contents can only be accessed when the data safe is open."
: ""

, "Usage"
: ""

, "This folder has own quota"
: ""

, "Quota"
: ""

, "No quota set (examples: 10 GB, 900 MB)"
: ""

, "Current Usage"
: ""

, "The quota applies recursively to files and subfolders. Please note, the effective quota can differ if a parent folder has set a lower quota."
: ""

, "File Type"
: ""

, "Usage by File Type"
: ""

, "User"
: ""

, "Usage by User"
: ""

, "unknown"
: ""

, "Reload"
: ""

, "Create Folder"
: "Luo kansio"

, "New Folder"
: "Uusi kansio"

, "Please enter the name of the new folder:"
: "Kirjoita uuden kansion nimi:"

, "No {0} added"
: "{0} ei lisätty"

, "You have to supply a {0} name!"
: "Anna {0} nimi."

, "Edit Properties"
: "Muokkaa asetuksia"

, "Rename"
: ""

, "Rename {0}"
: ""

, "Please enter the new name of the {0}:"
: "Nimeä uudestaan tiedosto {0}:"

, "Not renamed {0}"
: "Ei uudelleen nimetty {0}"

, "System Link"
: ""

, "Use this link to share the entry with other system users"
: ""

, "Delete"
: "Poista"

, "Do you really want to delete the following files?"
: "Haluatko poistaa seuraavat tiedostot?"

, "Move"
: ""

, "Move Items"
: ""

, "Preview"
: ""

, "Download links can be protected with a password. If no password is specified, anyone who knows the link can access the selected files."
: ""

, "Folder has been published successfully"
: ""

, "File has been published successfully"
: ""

, "Public Download URL"
: ""

, "Deliver anonymous downloads from another URL. Make sure the rewrite rules are adjusted accordingly."
: ""

, "you can't remove your own admin grant"
: ""

, "My folders"
: "Omat kansiot"

, "Shared folders"
: "Jaetut kansiot"

, "Other users folders"
: "Muiden käyttäjien kansiot"

, "Received"
: ""

, "To"
: ""

, "Cc"
: ""

, "Bcc"
: ""

, "From (E-Mail)"
: ""

, "From (Name)"
: ""

, "Body"
: ""

, "Attachments"
: ""

, "Destination is a Subfolder"
: ""

, "The destination is a subfolder. It is not allowed to copy or move a folder into one of its subfolders."
: ""

, "Destination has the same Path"
: ""

, "The destination has the same path as the source. No action has been performed."
: ""

, "manage shared folders"
: "hallitse jaettuja kansioita"

, "Create new shared folders"
: "Luo uusi jaettu kansio"

, "Manage anonymous download links"
: ""

, "Allow viewing, adding and deleting download links"
: ""





, "Folder"
: "Kansio"

, "File"
: "Tiedosto"

, "Download Link"
: ""

, "Once a Day"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
